Majority-n networks
-------------------

The file ``mockturtle/generators/majority.hpp`` implements several functions
to generate majority-n networks.

.. doxygenfunction:: mockturtle::majority5
.. doxygenfunction:: mockturtle::majority7
.. doxygenfunction:: mockturtle::majority9_12
.. doxygenfunction:: mockturtle::majority9_13
